"use strict";

/* to use:

- Recall this file has chrome privileges
- Cu.import in this file will work for any 'general firefox things' (Services,etc)
  but NOT for addon-specific libs
*/

/* eslint no-unused-vars: ["error", { "varsIgnorePattern": "(config|EXPORTED_SYMBOLS)" }]*/
var EXPORTED_SYMBOLS = ["config"];

var config = {
  // required STUDY key
  study: {
    /** Required for studyUtils.setup():
     *
     * - studyName
     * - endings:
     *   - map of endingName: configuration
     * - telemetry
     *   - boolean send
     *   - boolean removeTestingFlag
     *
     * All other keys are optional.
     */

    // required keys: studyName, endings, telemetry

    // will be used activeExperiments tagging
    studyName: "searchNudgesExperiment",

    /** **endings**
     * - keys indicate the 'endStudy' even that opens these.
     * - urls should be static (data) or external, because they have to
     *   survive uninstall
     * - If there is no key for an endStudy reason, no url will open.
     * - usually surveys, orientations, explanations
     */
    endings: {
      "user-disable": {
        baseUrl: "https://qsurvey.mozilla.com/s3/Nudges-Doorhanger",
      },
      expired: {
        baseUrl: "https://qsurvey.mozilla.com/s3/Nudges-Doorhanger",
      },
    },
    telemetry: {
      send: true, // assumed false. Actually send pings?
      removeTestingFlag: false, // Marks pings to be discarded, set true for to have the pings processed in the pipeline
      // TODO "onInvalid": "throw"  // invalid packet for schema?  throw||log
    },
  },

  // required LOG key
  log: {
    // Fatal: 70, Error: 60, Warn: 50, Info: 40, Config: 30, Debug: 20, Trace: 10, All: -1,
    bootstrap: {
      // Console.jsm uses "debug", whereas Log.jsm uses "Debug", *sigh*
      level: "debug",
    },
    studyUtils: {
      level: "Trace",
    },
  },

  // OPTION KEYS

  // a place to put an 'isEligible' function
  // Will run only during first install attempt
  async isEligible() {
    // get whatever prefs, addons, telemetry, anything!
    // Cu.import can see 'firefox things', but not package things.
    return true;
  },

  // Nudge study branches and weights
  weightedVariations: [
    {
      name: "doshow",
      weight: 1,
    },
    {
      name: "noshow",
      weight: 1,
    },
  ],

  // Optional: relative to bootstrap.js in the xpi
  studyUtilsPath: `./StudyUtils.jsm`,
};
